Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

### - s -

- scaled_add() : stan::math
- scaled_inv_chi_square_ccdf_log() : stan::math
- scaled_inv_chi_square_cdf() : stan::math
- scaled_inv_chi_square_cdf_log() : stan::math
- scaled_inv_chi_square_log() : stan::math
- scaled_inv_chi_square_rng() : stan::math
- sd() : stan::math
- segment() : stan::math
- set_zero_all_adjoints() : stan::math
- set_zero_all_adjoints_nested() : stan::math
- sign() : stan::math
- simplex_constrain() : stan::math
- simplex_free() : stan::math
- sin() : stan::math
- singular_values() : stan::math
- sinh() : stan::math
- size() : stan::math
- size_of() : stan
- skew_normal_ccdf_log() : stan::math
- skew_normal_cdf() : stan::math
- skew_normal_cdf_log() : stan::math
- skew_normal_log() : stan::math
- skew_normal_rng() : stan::math
- softmax() : stan::math
- sort_asc() : stan::math
- sort_desc() : stan::math
- sort_indices_asc() : stan::math
- sort_indices_desc() : stan::math
- sqrt() : stan::math
- sqrt2() : stan::math
- square() : stan::math
- squared_distance() : stan::math
- stan_print() : stan::math
- start_nested() : stan::math
- step() : stan::math
- student_t_ccdf_log() : stan::math
- student_t_cdf() : stan::math
- student_t_cdf_log() : stan::math
- student_t_log() : stan::math
- student_t_rng() : stan::math
- sub() : stan::math
- sub_col() : stan::math
- sub_row() : stan::math
- subtract() : stan::math
- sum() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.